pub struct HighlightConfig {
pub project_id: String,
pub service_name: Option<String>,
pub service_version: Option<String>,
pub logger: Box<dyn Log>,
}Fields
project_id: StringYour highlight.io Project ID
service_name: Option<String>The name of your app.
service_version: Option<String>The version of your app. We recommend setting this to the most recent deploy SHA of your app.
logger: Box<dyn Log>The current logger (implements log::Log).
By default, Highlight will initialize an env_logger for you, but if you want to provide a custom logger, you can specify it here. If you provide a custom logger, do not make it global, as Highlight will do it for you.